@@ -1,3 +1,6 @@
+#' @include hidden.R
+NULL
+
 #' DBIResult class
 #'
 #' This virtual class describes the result and state of execution of
@@ -24,18 +27,19 @@ setClass("DBIResult", contains = c("DBIObject", "VIRTUAL"))
 #' @rdname hidden_aliases
 #' @param object Object to display
 #' @export
-setMethod("show", "DBIResult", function(object) {
+setMethod("show", signature("DBIResult"), function(object) {
   # to protect drivers that fail to implement the required methods (e.g.,
   # RPostgreSQL)
   tryCatch(
     show_result(object),
-    error = function(e) NULL)
+    error = function(e) NULL
+  )
   invisible(NULL)
 })
 
 show_result <- function(object) {
   cat("<", is(object)[1], ">\n", sep = "")
-  if(!dbIsValid(object)){
+  if (!dbIsValid(object)) {
     cat("EXPIRED\n")
   } else {
     cat("  SQL  ", dbGetStatement(object), "\n", sep = "")
@@ -56,6 +60,9 @@ show_result <- function(object) {
 #' implementation for `dbFetch()` calls `fetch()` so that it is compatible with
 #' existing code. Modern backends should implement for `dbFetch()` only.
 #'
+#' @template methods
+#' @templateVar method_name dbFetch
+#'
 #' @inherit DBItest::spec_result_fetch return
 #' @inheritSection DBItest::spec_result_fetch Specification
 #' @inheritSection DBItest::spec_result_roundtrip Specification
@@ -97,7 +104,7 @@ setGeneric("dbFetch",
 
 #' @rdname hidden_aliases
 #' @export
-setMethod("dbFetch", "DBIResult", function(res, n = -1, ...) {
+setMethod("dbFetch", signature("DBIResult"), function(res, n = -1, ...) {
   fetch(res, n = n, ...)
 })
 
@@ -114,6 +121,9 @@ setGeneric("fetch",
 #' cases (e.g., very large result sets) this can be a critical step to avoid
 #' exhausting resources (memory, file descriptors, etc.)
 #'
+#' @template methods
+#' @templateVar method_name dbClearResult
+#'
 #' @inherit DBItest::spec_result_clear_result return
 #' @inheritSection DBItest::spec_result_clear_result Specification
 #'
@@ -137,15 +147,14 @@ setGeneric("dbClearResult",
 #'
 #' Produces a data.frame that describes the output of a query. The data.frame
 #' should have as many rows as there are output fields in the result set, and
-#' each column in the data.frame should describe an aspect of the result set
+#' each column in the data.frame describes an aspect of the result set
 #' field (field name, type, etc.)
 #'
 #' @inheritParams dbClearResult
-#' @return A data.frame with one row per output field in `res`. Methods
-#'   MUST include `name`, `field.type` (the SQL type),
-#'   and `data.type` (the R data type) columns, and MAY contain other
-#'   database specific information like scale and precision or whether the
-#'   field can store `NULL`s.
+#'
+#' @inherit DBItest::spec_meta_column_info return
+#' @inheritSection DBItest::spec_meta_column_info Specification
+#'
 #' @family DBIResult generics
 #' @export
 #' @examples
@@ -167,6 +176,9 @@ setGeneric("dbColumnInfo",
 #' Returns the statement that was passed to [dbSendQuery()]
 #' or [dbSendStatement()].
 #'
+#' @template methods
+#' @templateVar method_name dbGetStatement
+#'
 #' @inherit DBItest::spec_meta_get_statement return
 #'
 #' @inheritParams dbClearResult
@@ -193,6 +205,9 @@ setGeneric("dbGetStatement",
 #' A `SELECT` query is completed if all rows have been fetched.
 #' A data manipulation statement is always completed.
 #'
+#' @template methods
+#' @templateVar method_name dbHasCompleted
+#'
 #' @inherit DBItest::spec_meta_has_completed return
 #' @inheritSection DBItest::spec_meta_has_completed Specification
 #'
@@ -224,6 +239,9 @@ setGeneric("dbHasCompleted",
 #' This method returns the number of rows that were added, deleted, or updated
 #' by a data manipulation statement.
 #'
+#' @template methods
+#' @templateVar method_name dbGetRowsAffected
+#'
 #' @inherit DBItest::spec_meta_get_rows_affected return
 #'
 #' @inheritParams dbClearResult
@@ -250,6 +268,9 @@ setGeneric("dbGetRowsAffected",
 #' Returns the total number of rows actually fetched with calls to [dbFetch()]
 #' for this result set.
 #'
+#' @template methods
+#' @templateVar method_name dbGetRowCount
+#'
 #' @inherit DBItest::spec_meta_get_row_count return
 #'
 #' @inheritParams dbClearResult
@@ -284,7 +305,7 @@ setGeneric("dbGetRowCount",
 #' [dbGetRowsAffected()], and [dbHasCompleted()].
 NULL
 #' @rdname hidden_aliases
-setMethod("dbGetInfo", "DBIResult", function(dbObj, ...) {
+setMethod("dbGetInfo", signature("DBIResult"), function(dbObj, ...) {
   list(
     statement = dbGetStatement(dbObj),
     row.count = dbGetRowCount(dbObj),
@@ -327,6 +348,9 @@ setMethod("dbGetInfo", "DBIResult", function(dbObj, ...) {
 #' - `$1` (positional matching by index) in \pkg{RPostgres} and \pkg{RSQLite}
 #' - `:name` and `$name` (named matching) in \pkg{RSQLite}
 #'
+#' @template methods
+#' @templateVar method_name dbBind
+#'
 #' @inherit DBItest::spec_meta_bind return
 #' @inheritSection DBItest::spec_meta_bind Specification
 #'
